<?php

if (!defined('_PS_VERSION_'))
	exit;

class BlockCallback extends Module
{
	public function __construct()
	{
		$this->name = 'blockcallback';
		$this->tab = 'front_office_features';
		$this->version = '0.2';
		$this->author = 'WebDreamLab.com';
		$this->need_instance = 0;

		parent::__construct();

		$this->displayName = $this->l('Передзвоніть мені');
		$this->description = $this->l('Форма запиту зворотнього дзвінка');
	}

	public function install()
	{
		if(!parent::install() ||
			!$this->registerHook('leftColumn') ||
			!$this->registerHook('header') ||
			!$this->installConfiguration() ||
			!$this->_installModuleTab())
		{
			return false;
		}

		return Db::getInstance()->Execute('
			CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'blockcallback` (
				`id_blockcallback` INT NOT NULL AUTO_INCREMENT,
				`name` VARCHAR(255) NOT NULL,
				`phone` VARCHAR(255) NOT NULL,
				`active` TINYINT(1) NOT NULL DEFAULT \'0\',
				`created` DATETIME NULL,
				`color` VARCHAR(7) DEFAULT \'#FEEFB3\',
				`ip` VARCHAR(15) NOT NULL,
				PRIMARY KEY(`id_blockcallback`)
			) ENGINE='._MYSQL_ENGINE_.' default CHARSET=utf8');
	}

	public function uninstall()
	{
		if(!parent::uninstall())
			return false;

		$this->uninstallConfiguration();
		$this->_uninstallModuleTab();

		return Db::getInstance()->Execute('DROP TABLE IF EXISTS '._DB_PREFIX_.'blockcallback');
	}

	protected function installConfiguration()
	{
		return Configuration::updateValue('CALLBACK_EMAIL', '');
	}

	protected function uninstallConfiguration()
	{
		return Configuration::deleteByName('CALLBACK_EMAIL');
	}

	protected function _installModuleTab()
	{
		$tab = new Tab();
		$tab->class_name = 'AdminCallback';
		$tab->id_parent = (int)Tab::getIdFromClassName('AdminCustomers');
		$tab->module = 'blockcallback';

		foreach(Language::getLanguages(false) as $lang)
			$tab->name[(int)$lang['id_lang']] = 'Call Back';

		if(!$tab->save())
		{
			return false;
		}

		@copy(dirname(__FILE__).'/logo.gif', _PS_IMG_DIR_.'t/AdminCallback.gif');

		return true;
	}

	protected function _uninstallModuleTab()
	{
		if($id_tab = Tab::getIdFromClassName('AdminCallback'))
		{
			$tab = new Tab((int)$id_tab);
			$tab->delete();

			@unlink(_PS_IMG_DIR_.'t/AdminCallback.gif');
		}
	}

	function hookHeader($params)
	{
		if(method_exists('Tools', 'addCSS'))
		{
            $this->context->controller->addCSS($this->_path.'css/smsmodule.css', 'all');
            $this->context->controller->addJS($this->_path.'js/script.js', 'all');
            $this->context->controller->addJS($this->_path.'js/jquery.bxslider.js', 'all');
            $this->context->controller->addJS($this->_path.'js/select2.min.js', 'all');
            $this->context->controller->addJS($this->_path.'js/jquery.tooltipster.min.js', 'all');

			//Tools::addCSS($this->_path.'blockcallback.css', 'all');
		}
		else
		{
			return '<link href="'._MODULE_DIR_.$this->name.'/blockcallback.css" rel="stylesheet" type="text/css" media="all" />'."\n".
				'<style type="text/css">#blockcallback_block_left input.exclusive { display: inline-block; width: 120px; }</style>'."\n";
		}
	}

	public function hookLeftColumn($params)
	{
		if(!$this->isVisible())
			return;

		$this->_processInput();
		return $this->display(__FILE__, 'blockcallback.tpl');
	}

	public function hookRightColumn($params)
	{
		return $this->hookLeftColumn($params);
	}

	protected function isVisible()
	{
		return true;
	}


    public static function send($number, $text){

        $sender = Configuration::get('CALLBACK_PIDPYS');
        $login = Configuration::get('SHLUSE_LOGIN');
        $pwd = Configuration::get('SHLUSE_PASSWORD');

        // connect from server
        $client = new SoapClient ('http://turbosms.in.ua/api/wsdl.html');
        $auth = array(
            'login' => $login,
            'password' => $pwd
        );

        // authorise on server
        $res = $client->Auth ($auth);


        // get much credits
        $result = $client->GetCreditBalance ();
        echo $result->GetCreditBalanceResult;

        $text = iconv ('utf-8', 'utf-8', $text);
        // Date send
        $sms = Array (
            'sender' => $sender,
            'destination' => $number,
            'text' => $text
        );

        $result = $client->SendSMS ($sms);



    }

	protected function _processInput()
	{
		global $smarty;

        $my_number = Configuration::get('CALLBACK_MY_NUMBER');

		if(Tools::isSubmit('submitBlockCallback'))
		{
			$error = false;
			$msg = '';

			if(!$this->_validateName())
			{
				$error = true;
				$msg = $this->l('Enter your name');
			}
			else if(!$this->_validatePhone())
			{
				$error = true;
				$msg = $this->l('Enter valid phone number');
			}
			else
			{
				if($this->_save($_POST['BlockCallbackName'], $_POST['BlockCallbackPhone']))
				{
                    if(Configuration::get('CALLBACK_SEND_EMAIL') == 1) {
					    $this->_notify($_POST['BlockCallbackName'], $_POST['BlockCallbackPhone']);
                    }
                    if(Configuration::get('CALLBACK_SEND_PHONE') == 1) {
                        $this->send($my_number, $_POST['BlockCallbackPhone'].' - '.$_POST['BlockCallbackName'].'. Ordered callback from '.$_SERVER['SERVER_NAME']);
                    }

                    echo '<style>a.popup {display: none !important;}</style>';
					$msg = $this->l("<p style='font-size: 14px; color: green; font-weight: bold;'>Дякуємо. Наш менеджер з вами зв'яжеться</p>");

				}
				else
				{
					$error = true;
					$msg = $this->l('Internal error');
				}
			}

			$smarty->assign(array(
				'blockcallback_error' => $error,
				'blockcallback_msg' => $msg,
			));
		}
	}

	protected function _validateName()
	{
		return !empty($_POST['BlockCallbackName']);
	}

	protected function _validatePhone()
	{
		return !empty($_POST['BlockCallbackPhone']) && preg_match('/^[-+()0-9 ]{3,}$/', $_POST['BlockCallbackPhone']);
	}

	protected function _save($name, $phone)
	{
		$remoteAddr = method_exists('Tools', 'getRemoteAddr') ? Tools::getRemoteAddr() : $_SERVER['REMOTE_ADDR'];
		return Db::getInstance()->Execute('INSERT INTO `'._DB_PREFIX_.'blockcallback` (`name`, `phone`, `created`, `ip`) VALUES (\''.pSQL($name).'\', \''.pSQL($phone).'\', NOW(), \''.pSQL($remoteAddr).'\')');

	}



	protected function _notify($name, $phone)
	{
		$email = Configuration::get('CALLBACK_EMAIL');
        $id_lang = '1';
        $iso = 'ru';
		if(empty($email))
		{
			return true;
		}


		$id_lang = (int)Configuration::get('PS_LANG_DEFAULT');
		$iso = Language::getIsoById($id_lang);

		$templateVars = array(
			'{customer_name}' => $name,
			'{customer_phone}' => $phone,
		);



		if(file_exists(dirname(__FILE__).'/mails/'.$iso.'/callback.txt') &&
			file_exists(dirname(__FILE__).'/mails/'.$iso.'/callback.html'))
		{


			Mail::Send($id_lang, 'callback', $this->l('Call back request'), $templateVars, strval($email), NULL, strval(Configuration::get('PS_SHOP_EMAIL')), strval(Configuration::get('PS_SHOP_NAME')), NULL, NULL, dirname(__FILE__).'/mails/');
		}

        return true;
	}

	public function getContent()
	{
		global $smarty;

		$output = '<h2>'.$this->displayName.'</h2>';

		if(Tools::isSubmit('btnSubmitBlockCallback'))
		{
			$errors = array();

			$email = Tools::getValue('CALLBACK_EMAIL');
            $my_number = Tools::getValue('CALLBACK_MY_NUMBER');
            $login_shluse = Tools::getValue('SHLUSE_LOGIN');
            $password_shluse = Tools::getValue('SHLUSE_PASSWORD');
            $pidpys = Tools::getValue('CALLBACK_PIDPYS');
            $send_phone = Tools::getValue('CALLBACK_SEND_PHONE')=='on'?1:0;
            $send_email = Tools::getValue('CALLBACK_SEND_EMAIL')=='on'?1:0;

			if(!empty($email) && !Validate::isEmail($email))
			{
				$errors[] = $this->l('Invalid email address');
			}

			if(empty($errors))
			{
                Configuration::updateValue('CALLBACK_MY_NUMBER', $my_number);
				Configuration::updateValue('CALLBACK_EMAIL', $email);

                Configuration::updateValue('SHLUSE_LOGIN', $login_shluse);
                Configuration::updateValue('SHLUSE_PASSWORD', $password_shluse);
                Configuration::updateValue('CALLBACK_PIDPYS', $pidpys);

                Configuration::updateValue('CALLBACK_SEND_PHONE', $send_phone);
                Configuration::updateValue('CALLBACK_SEND_EMAIL', $send_email);
			}

			if(!empty($errors))
				$output .= $this->displayError(implode('<br />', $errors));
			else
				$output .= $this->displayConfirmation($this->l('Settings updated'));
		}

		$smarty->assign(array(
            'CALLBACK_MY_NUMBER' => Configuration::get('CALLBACK_MY_NUMBER'),
			'CALLBACK_EMAIL' => Configuration::get('CALLBACK_EMAIL'),
            'SHLUSE_LOGIN' => Configuration::get('SHLUSE_LOGIN'),
            'SHLUSE_PASSWORD' => Configuration::get('SHLUSE_PASSWORD'),
            'CALLBACK_PIDPYS' => Configuration::get('CALLBACK_PIDPYS'),
            'CALLBACK_SEND_PHONE' => Configuration::get('CALLBACK_SEND_PHONE'),
            'CALLBACK_SEND_EMAIL' => Configuration::get('CALLBACK_SEND_EMAIL'),
		));

		$output .= $this->display(__FILE__, 'settings.tpl');

		return $output;
	}
}
